==> accounts_management-0.1.6.gem: app/controllers/accounts_management/ledgers/ledgers_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgersController < AccountsManagementController
    # GET /ledgers/ledgers
    # GET /ledgers/ledgers.json
    def index
      @ledgers_ledgers = Ledgers::Ledger.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @ledgers_ledgers }
      end
    end

    # GET /ledgers/ledgers/1
    # GET /ledgers/ledgers/1.json
    def show
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @ledgers_ledger }
      end
    end

    # GET /ledgers/ledgers/new
    # GET /ledgers/ledgers/new.json
    def new
      @ledgers_ledger = Ledgers::Ledger.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @ledgers_ledger }
      end
    end

    # GET /ledgers/ledgers/1/edit
    def edit
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])
    end

    # POST /ledgers/ledgers
    # POST /ledgers/ledgers.json
    def create
      @ledgers_ledger = Ledgers::Ledger.new(params[:ledgers_ledger])

      respond_to do |format|
        if @ledgers_ledger.save
          format.html { redirect_to @ledgers_ledger, :notice => 'Ledger was successfully created.' }
          format.json { render :json => @ledgers_ledger, :status => :created, :location => @ledgers_ledger }
        else
          format.html { render :action => "new" }
          format.json { render :json => @ledgers_ledger.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledgers/1
    # PUT /ledgers/ledgers/1.json
    def update
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger.update_attributes(params[:ledgers_ledger])
          format.html { redirect_to @ledgers_ledger, :notice => 'Ledger was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @ledgers_ledger.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledgers/1
    # DELETE /ledgers/ledgers/1.json
    def destroy
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])
      @ledgers_ledger.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledgers_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/ledgers/ledgers_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgersController < AccountsManagementController
    # GET /ledgers/ledgers
    # GET /ledgers/ledgers.json
    def index
      @ledgers_ledgers = Ledgers::Ledger.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @ledgers_ledgers }
      end
    end

    # GET /ledgers/ledgers/1
    # GET /ledgers/ledgers/1.json
    def show
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @ledgers_ledger }
      end
    end

    # GET /ledgers/ledgers/new
    # GET /ledgers/ledgers/new.json
    def new
      @ledgers_ledger = Ledgers::Ledger.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @ledgers_ledger }
      end
    end

    # GET /ledgers/ledgers/1/edit
    def edit
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])
    end

    # POST /ledgers/ledgers
    # POST /ledgers/ledgers.json
    def create
      @ledgers_ledger = Ledgers::Ledger.new(params[:ledgers_ledger])

      respond_to do |format|
        if @ledgers_ledger.save
          format.html { redirect_to @ledgers_ledger, notice: 'Ledger was successfully created.' }
          format.json { render json: @ledgers_ledger, status: :created, location: @ledgers_ledger }
        else
          format.html { render action: "new" }
          format.json { render json: @ledgers_ledger.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledgers/1
    # PUT /ledgers/ledgers/1.json
    def update
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger.update_attributes(params[:ledgers_ledger])
          format.html { redirect_to @ledgers_ledger, notice: 'Ledger was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @ledgers_ledger.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledgers/1
    # DELETE /ledgers/ledgers/1.json
    def destroy
      @ledgers_ledger = Ledgers::Ledger.find(params[:id])
      @ledgers_ledger.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledgers_url }
        format.json { head :no_content }
      end
    end
  end
end
